@@ -23,32 +23,34 @@
 #include "timelinesettings.h"
 
 TimelineSettings::TimelineSettings(QGraphicsWidget *parent)
-    : TwitterApplicationItem(parent)
+    : TwitterApplicationItem(parent),
+      _startPos(QPointF(0, 0)),
+      _endPos(QPointF(0, 0)),
+      _anim(false)
 {
-    this->setGeometry(0, 0, 800, 480);
-
     // back button
     _backButton = new TwitterButton(TwitterButton::Back,"",this);
-    _backButton->setPos(714, 0);
     connect(_backButton, SIGNAL(released()), this, SLOT(_exitAnimation()));
 
     // line separator
-    _sep1 = new QGraphicsLineItem(20, 403, 780, 403, this);
+    _sep1 = new QGraphicsLineItem(this);
     _sep1->setPen(QPen(QColor("#0f95da")));
 
     // Logout Button
     _logoutButton = new TwitterButton(TwitterButton::Generic,"Logout",this);
-    _logoutButton->setPos(679,413);
 
     // Infos
     _infos = new QGraphicsTextItem(this);
-    _infos->setPos(20,425);
 
     QString messageHtml = "<p style=\" font-size:18px; padding-bottom:0px; margin-bottom:0px; font-family:'Nokia Sans';\"> ";
-    messageHtml += "<span style=\" color:#0f95da ;\">TweeGo Copyright &copy; 2010 v0.5.1 by Mikhail Ramalho</span></p>";
+    messageHtml += "<span style=\" color:#0f95da ;\">TweeGo Copyright &copy; 2010 v0.6.0 by Mikhail Ramalho</span></p>";
     _infos->setHtml(messageHtml);
 
     connect(_logoutButton, SIGNAL(released()), SLOT(_logout()));
+
+    // Change Orientation
+    _changeOrientation();
+    connect(QApplication::desktop(), SIGNAL(resized(int)), SLOT(_changeOrientation()));
 }
 
 void TimelineSettings::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
@@ -64,9 +66,11 @@ void TimelineSettings::paint(QPainter *painter, const QStyleOptionGraphicsItem *
 
 void TimelineSettings::startAnimation(void)
 {
+    _anim = true;
+
     QPropertyAnimation *mvWhiteRect = new QPropertyAnimation(this,"pos");
-    mvWhiteRect->setStartValue(QPointF(0,480));
-    mvWhiteRect->setEndValue(QPointF(0,0));
+    mvWhiteRect->setStartValue(_startPos);
+    mvWhiteRect->setEndValue(_endPos);
     mvWhiteRect->setDuration(250);
     mvWhiteRect->setEasingCurve(QEasingCurve::Linear);
     mvWhiteRect->start();
@@ -74,9 +78,11 @@ void TimelineSettings::startAnimation(void)
 
 void TimelineSettings::_exitAnimation(void)
 {
+    _anim = false;
+
     QPropertyAnimation *mvWhiteRect = new QPropertyAnimation(this,"pos");
-    mvWhiteRect->setStartValue(QPointF(0,0));
-    mvWhiteRect->setEndValue(QPointF(0,480));
+    mvWhiteRect->setStartValue(_endPos);
+    mvWhiteRect->setEndValue(_startPos);
     mvWhiteRect->setDuration(250);
     mvWhiteRect->setEasingCurve(QEasingCurve::Linear);
     mvWhiteRect->start();
@@ -92,3 +98,31 @@ void TimelineSettings::_logout()
     _exitAnimation();
     emit logout();
 }
+
+void TimelineSettings::_changeOrientation(void)
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    resize(screenGeometry.size());
+
+    if(screenGeometry.width() > screenGeometry.height()) {
+        _logoutButton->setPos(size().width() - _logoutButton->size().width() - 35, 417);
+        _infos->setPos(35, 425);
+
+        _startPos = QPointF(0, 480);
+
+    } else if(screenGeometry.width() < screenGeometry.height()) {
+        _logoutButton->setPos((size().width() - _logoutButton->size().width())/2, 733);
+        _infos->setPos(35, _logoutButton->pos().y() - _infos->boundingRect().height() - 10);
+
+        _startPos = QPointF(0, 800);
+    }
+
+    if(_anim) {
+        setPos(_endPos);
+    } else {
+        setPos(_startPos);
+    }
+
+    _sep1->setLine(_infos->pos().x() - 15, _infos->pos().y() - 15, size().width() - 20, _infos->pos().y() - 15);
+    _backButton->setPos(size().width() - _backButton->size().width(), 0);
+}
