@@ -22,26 +22,41 @@
 
 #include "user.h"
 
-User::User(QString username, QImage avatar, int pos, QGraphicsWidget *parent)
+User::User(QString username, QImage avatar, QGraphicsWidget *parent)
     : TwitterApplicationItem(parent),
     _defaultAvatar(QImage(":images/resources/avatar.png")),
     _username(QString(username)),
-    _bgColor(QColor(246,253,255)),
-    _pos(pos)
+    _bgColor(QColor(246,253,255))
 {
-    this->setMinimumSize(299,74);
+    setMinimumSize(310,74);
 
     // Draw default avatar if the user is new
-    if(avatar.isNull())
-        _avatar = _defaultAvatar;
-    else
-        _avatar = avatar;
+    _avatar = new QGraphicsPixmapItem(this);
+    _avatar->setPos(13, 13);
+    _avatar->setZValue(2.0);
+
+    if(avatar.isNull()) {
+        _avatar->setPixmap(QPixmap::fromImage(_defaultAvatar));
+    } else {
+        _avatar->setPixmap(QPixmap::fromImage(avatar));
+    }
 
     // Create text object to draw on the screen
     _name = new QGraphicsTextItem(this);
 
+    // Create Rects
+    _avatarRect = new QGraphicsRectItem(this);
+    _avatarRect->setBrush(QBrush(QColor(246, 253, 255)));
+    _avatarRect->setRect(13, 13, 48, 48);
+    _avatarRect->setPen(Qt::NoPen);
+    _avatarRect->setZValue(1.0);
+
     // Draw username on the screen
-    drawName(true);
+    drawName(false);
+
+    // Set Orientation
+    _changeOrientation();
+    connect(QApplication::desktop(), SIGNAL(resized(int)), SLOT(_changeOrientation()));
 }
 
 void User::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
@@ -52,12 +67,7 @@ void User::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWid
     painter->setBrush(_bgColor);
     painter->setPen(Qt::NoPen);
     painter->setRenderHint(QPainter::Antialiasing);
-    painter->drawRoundedRect(0, 0, rect().width()-10, rect().height(), 2, 2);
-
-    painter->setBrush(QColor(246,253,255));
-    painter->drawRect(13,13,48,48);
-
-    painter->drawImage(QRect(13,13,48,48),_avatar);
+    painter->drawRoundedRect(0, 0 , rect().width() - 10, rect().height(), 2, 2);
 }
 
 void User::mousePressEvent(QGraphicsSceneMouseEvent *event)
@@ -75,26 +85,51 @@ void User::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 void User::unselect(void)
 {
     _bgColor = QColor(246,253,255);
+    drawName(false);
     update();
-    drawName(true);
 }
 
 void User::drawName(bool isSelected)
 {
     QString colorHex = "#ffffff";;
-    if(isSelected)
+    if(!isSelected)
         colorHex = "#0f95da";
 
     QString messageHtml = "<p style=\" font-size:18px; padding-bottom:0px; margin-bottom:0px; font-family:'Nokia Sans';\"> ";
     messageHtml += "<span style=\" color:" + colorHex + ";\">" + _username + "</span></p>";
     _name->setHtml(messageHtml);
-    _name->setPos(74,(rect().height() - _name->boundingRect().height())/2);
 }
 
 void User::select(void)
 {
     _bgColor = QColor(0,173,239);
+    drawName(true);
     update();
-    emit selected(_pos);
-    drawName(false);
+
+    emit selected(this);
+}
+
+QString User::getUsername(void)
+{
+    return _username;
+}
+
+void User::_changeOrientation(void)
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+
+    setMinimumSize(-1, -1);
+    setMaximumSize(-1, -1);
+
+    if(screenGeometry.width() > screenGeometry.height()) {
+        _name->setTextWidth(240);
+        setMinimumSize(310, 74);
+        setMaximumSize(310, 74);
+    } else if (screenGeometry.width() < screenGeometry.height()) {
+        _name->setTextWidth(400);
+        setMinimumSize(475, 74);
+        setMaximumSize(475, 74);
+    }
+
+    _name->setPos(74, (rect().height() - _name->boundingRect().height())/2);
 }
