@@ -52,19 +52,9 @@ Backend *Backend::getInstance(void)
  */
 Backend::Backend()
     : twitterapi( new TwitterAPI ),
-    friendsPage(1),
-    mentionsPage(1)
+      mentionsPage(1),
+      friendsPage(1)
 {
-//    QSettings settings("Zagaia","TweeGo");
-//        settings.beginGroup("PROXY");
-//        if(settings.value("useProxy").toBool()) {
-//            m_twitLib->SetProxy(SERVER::HTTP_PROXY, settings.value("ip").toString(),
-//                                settings.value("port").toInt(),
-//                                settings.value("user").toString(),
-//                                settings.value("pass").toString());
-//        }
-//        settings.endGroup();
-
     twitterapi->setServiceUrl("https://twitter.com");
     twitterapi->setUsingOAuth(true);
 
@@ -91,33 +81,43 @@ void Backend::_parseEntries(EntryList entries)
     int lastConn = conns.at(0);
     conns.removeAt(0);
 
-    foreach( const Entry &entry, entries ) {
-        if(entry.isOwn)
-            userInformations = entry.userInfo;
-    }
-
-    _addNewTweets(entries);
-
     switch(lastConn)
     {
         case Connection::GetFriendsTimeline:
+            _addNewHomeTweets(entries);
             emit gotFriendsTimeline();
             break;
 
         case Connection::Update:
+            _addNewHomeTweets(entries);
             emit updatePosted();
             break;
 
         case Connection::GetMentions:
+            _addNewMentionsTweets(entries);
             emit gotMentions();
             break;
     }
 }
 
-void Backend::_addNewTweets(EntryList entries)
+void Backend::_addNewHomeTweets(EntryList entries)
 {
-    //TODO: remove duplicated tweets, maybe QMap<int,Entry*>
-    _tweets = entries;
+    foreach( Entry entry, entries) {
+        if(!_homeTweetsMap.contains(entry.id)) {
+            _homeTweetsMap[entry.id] = entry;
+            _homeTweets << entry;
+        }
+    }
+}
+
+void Backend::_addNewMentionsTweets(EntryList entries)
+{
+    foreach( Entry entry, entries) {
+        if(!_mentionsTweetsMap.contains(entry.id)) {
+            _mentionsTweetsMap[entry.id] = entry;
+            _mentionsTweets << entry;
+        }
+    }
 }
 
 /*!
@@ -146,15 +146,22 @@ void Backend::getTimeline(Timeline::TimelineType type)
         case Timeline::Users:
             // TODO: implement twitterapi->userTimeline().
             break;
+
         case Timeline::Friends:
+            _homeTweets.clear();
+
             conns << Connection::GetFriendsTimeline;
             twitterapi->friendsTimeline(friendsPage);
             friendsPage++;
             break;
+
         case Timeline::Public:
             twitterapi->publicTimeline();
             break;
+
         case Timeline::Mentions:
+            _mentionsTweets.clear();
+
             conns << Connection::GetMentions;
             twitterapi->mentions(mentionsPage);
             mentionsPage++;
@@ -181,27 +188,37 @@ UserInfo Backend::userInfo()
     return userInformations;
 }
 
-EntryList Backend::tweets(void)
+EntryList Backend::homeTweets(void)
 {
-    return _tweets;
+    return _homeTweets;
 }
 
-/*!
- * \brief Sets which friends timeline page to download.
- * \param page Page number.
- */
-void Backend::setFriendsPage(int page)
+EntryList Backend::mentionsTweets(void)
 {
-    friendsPage = page;
+    return _mentionsTweets;
 }
 
-/*!
- * \brief Sets which user timeline page to download.
- * \param page Page number.
- */
-void Backend::setUsersPage(int page)
+void Backend::resetTimelinePage(Timeline::TimelineType type)
 {
-    userPage = page;
+    switch(type) {
+        case Timeline::Friends:
+            _homeTweetsMap.clear();
+            _homeTweets.clear();
+
+            friendsPage = 1;
+            break;
+
+        case Timeline::Mentions:
+            _mentionsTweetsMap.clear();
+            _mentionsTweets.clear();
+
+            mentionsPage = 1;
+            break;
+
+        case Timeline::Users:
+            userPage = 1;
+            break;
+    }
 }
 
 /*!
@@ -278,15 +295,6 @@ bool Backend::updateProfileImage(QString image)
     return false;
 }
 
-/*!
- * \brief Sets which mentions timeline page to download.
- * \param page Page number.
- */
-void Backend::setMentionsPage(int page)
-{
-    mentionsPage = page;
-}
-
 void Backend::setConsumerKey(const QByteArray &consumerKey)
 {
     twitterapi->setConsumerKey(consumerKey);
