@@ -25,18 +25,18 @@
 
 #include "applicationItems/twittercheckbox.h"
 #include "applicationItems/lineedit.h"
-#include "applicationItems/loader.h"
 #include "applicationItems/twitterbutton.h"
 #include "applicationItems/loginsettings.h"
 #include "applicationItems/oauthwizard.h"
 #include "applicationItems/kineticlist.h"
+#include "applicationItems/dialog.h"
 
 /*!
  * \class LoginView
  *
  * \brief Login window with customized widgets.
  */
-class LoginView : public QGraphicsWidget
+class LoginView : public TwitterApplicationItem
 {
     Q_OBJECT
 
@@ -50,30 +50,36 @@ public slots:
     void connected(void);
     void connectionError(void);
     void emitLoginAccount(void);
+    void exitLogin(void);
 
 private slots:
-    void _connecting(void);
-    void _deleteLoader(void);
     void _endLogin(void);
-    void _animSettings(void);
+    void _removeAccountDialog(void);
+    void _accountRemoved(void);
+    void _changeOrientation(void);
+    void _unlockRotation(void);
+    void _lockRotation(void);
 
 signals:
-    void exitLogin(void);
+    void exitApp(void);
     void loginAccount(void);
     void rememberMe(void);
     void done(void);
     void abort(void);
     void newAccount(void);
+    void accRemoved(void);
+    void lockRotation(bool);
 
 private:
     QAbstractAnimation *_createEntryAnimation(void);
-    QAbstractAnimation *_createExitAnimation();
+    QAbstractAnimation *_createExitAnimation(void);
     void _createButtons(void);
     void _createLogo(void);
     void _createLoginBackground(void);
     void _createSettings(void);
     void _createOauthWizard(void);
     void _createUsersList(void);
+    void _createAnimation(void);
     void _addOpacityAnim(QParallelAnimationGroup *anim,
                          TwitterApplicationItem *item,
                          int delay);
@@ -81,12 +87,14 @@ private:
                      TwitterApplicationItem *item,
                      QPointF startValue, QPointF endValue,
                      QEasingCurve easing, int delay);
+    void _emitLockRotation(bool lock);
 
 private:
     QAbstractAnimation *_exitAnim;
     QAbstractAnimation *_entryAnim;
-    QGraphicsRectItem *m_background;
+    QGraphicsRectItem *_background;
     QGraphicsPixmapItem *_logo;
+    DialogView *_dialog;
     TwitterButton *_loginButton;
     TwitterButton *_exitButton;
     TwitterButton *_exposeButton;
@@ -94,7 +102,12 @@ private:
     TwitterButton *_newAccountButton;
     LoginSettings *_settingsDialog;
     OauthWizard *_oauthWizard;
-    Loader *_loader;
+
+    QPointF _loginButtonPos;
+    QPointF _exitButtonPos;
+    QPointF _settingsButtonPos;
+    QPointF _newAccountButtonPos;
+
 };
 
 #endif // LOGINVIEW_H
