@@ -27,11 +27,11 @@
  */
 TimelineView::TimelineView(void) :
         timelineOnScreen(NULL),
-        leftPos(-801,60),
-        centerPos(0,60),
-        rightPos(801,60)
+        _leftPos(-801,60),
+        _centerPos(0,60),
+        _rightPos(801,60)
 {
-    _exitAnim = 0;
+    _exitAnim = NULL;
 }
 
 /*!
@@ -45,19 +45,39 @@ void TimelineView::createUi(void)
     _createTopBar();
     _createTimeline();
 
-    startLoader();
+    _unlockRotation();
+
+    _changeOrientation();
+    connect(QApplication::desktop(), SIGNAL(resized(int)), SLOT(_changeOrientation()));
+
+    _lockRotation();
 
-    /* Animations */
     _entryAnim = _createEntryAnimation();
     _entryAnim->start();
-    _exitAnim = _createExitAnimation();
 
-    connect(qobject_cast<QObject *>(_exitAnim), SIGNAL(finished()), SIGNAL(done()));
+    _createAnimation();
 
+    startLoader();
+
+    connect(_entryAnim, SIGNAL(finished()), SLOT(_unlockRotation()));
+    connect(_entryAnim, SIGNAL(finished()), SLOT(_changeOrientation()));
 //    connect(_locationCheckBox, SIGNAL(pressed()), this, SIGNAL(showLocationDialog()));
 //    connect(_ipLocation, SIGNAL(finished(double, double)), this, SLOT(_showIpLocationInfo(double, double)));
 }
 
+void TimelineView::_createAnimation(void)
+{
+    if(_exitAnim != NULL) {
+        if(_exitAnim->state() == QAbstractAnimation::Running)
+            return;
+
+        delete _exitAnim;
+    }
+
+    _exitAnim = _createExitAnimation();
+    connect(_exitAnim, SIGNAL(finished()), SIGNAL(done()));
+}
+
 /*!
  * \brief This method creates the entry animation for all objects on the screen.
  * \return anim Entry animation.
@@ -71,9 +91,8 @@ QAbstractAnimation *TimelineView::_createEntryAnimation(void)
 
     /* Buttons */
     _addOpacityAnim(anim, _updateButton, 0);
-    _addPosAnim(anim, _updateButton, QPointF(800 - _updateButton->boundingRect().width(), 480 - (_updateButton->boundingRect().height()) - 50),
-                QPointF(800 - _updateButton->boundingRect().width(), 480 - (_updateButton->boundingRect().height())),
-                easingCurve, 0);
+    _addPosAnim(anim, _updateButton, _updateButtonPos - QPointF(0, 50), _updateButtonPos, easingCurve, 0);
+
     _addOpacityAnim(anim, _exposeButton, 0);
     _addPosAnim(anim, _exposeButton, QPointF(0, 50), QPointF(0, 0), easingCurve, 0);
 
@@ -83,8 +102,7 @@ QAbstractAnimation *TimelineView::_createEntryAnimation(void)
 
      /* Update Entry */
     _addOpacityAnim(anim, _entryUpdate, 0);
-    _addPosAnim(anim, _entryUpdate, QPointF(0, 480 - _entryUpdate->boundingRect().height() - 50),
-                QPointF(0, 480 - _entryUpdate->boundingRect().height()),easingCurve, 0);
+    _addPosAnim(anim, _entryUpdate, _entryUpdatePos - QPointF(0, 50), _entryUpdatePos, easingCurve, 0);
 
     return anim;
 }
@@ -109,12 +127,11 @@ QAbstractAnimation* TimelineView::_createExitAnimation(void)
 void TimelineView::_createTimeline()
 {
     _homeTimeline = new KineticList(KineticList::Vertical, QSizeF(800,360),this);
-    _homeTimeline->setPos(0,60);
     _homeTimeline->setZValue(1.0);
 
     _mentionsTimeline = new KineticList(KineticList::Vertical, QSizeF(800,360), this);
-    _mentionsTimeline->setPos(801,60);
     _mentionsTimeline->setZValue(1.0);
+    _mentionsTimeline->setPos(801, 60);
 
     timelineOnScreen = _homeTimeline;
 
@@ -144,7 +161,7 @@ void TimelineView::_createTopBar()
 void TimelineView::_createSettings()
 {
     _settingsDialog = new TimelineSettings(this);
-    _settingsDialog->setPos(0,560);
+    _settingsDialog->setPos(800, 0);
     _settingsDialog->setZValue(4.0);
 
     connect(_settingsDialog, SIGNAL(logout()), SLOT(_backToLogin()));
@@ -174,7 +191,6 @@ void TimelineView::_createEntry()
 {
     _entryUpdate = new LineEdit(LineEdit::Long,this);
     _entryUpdate->setOpacity(0);
-    _entryUpdate->setPos(QPointF(100,435));
     _entryUpdate->setZValue(3.0);
 
     connect(_entryUpdate, SIGNAL(enterPressed()), SLOT(_emitPostUpdate()));
@@ -276,7 +292,7 @@ void TimelineView::_toHome(void)
     KineticList *oldTimeline = timelineOnScreen;
     timelineOnScreen = _homeTimeline;
 
-    _moveTimelines(oldTimeline,timelineOnScreen);
+    _moveTimelines(oldTimeline, timelineOnScreen);
 }
 
 void TimelineView::_toMentions(void)
@@ -295,7 +311,7 @@ void TimelineView::_toMentions(void)
     KineticList *oldTimeline = timelineOnScreen;
     timelineOnScreen = _mentionsTimeline;
 
-    _moveTimelines(oldTimeline,timelineOnScreen);
+    _moveTimelines(oldTimeline, timelineOnScreen);
 }
 
 void TimelineView::_moveTimelines(KineticList *oldTimeline, KineticList *newTimeline)
@@ -304,9 +320,9 @@ void TimelineView::_moveTimelines(KineticList *oldTimeline, KineticList *newTime
     int indexNew = _timelines.indexOf(newTimeline);
 
     if(indexOld > indexNew) {
-        _moveToRight(oldTimeline,newTimeline);
+        _moveToRight(oldTimeline, newTimeline);
     } else {
-        _moveToLeft(oldTimeline,newTimeline);
+        _moveToLeft(oldTimeline, newTimeline);
     }
 }
 
@@ -314,13 +330,13 @@ void TimelineView::_moveToLeft(KineticList *oldTimeline, KineticList *newTimelin
 {
     QPropertyAnimation *anim1 = new QPropertyAnimation(oldTimeline,"pos");
     anim1->setStartValue(oldTimeline->pos());
-    anim1->setEndValue(leftPos);
+    anim1->setEndValue(_leftPos);
     anim1->setDuration(250);
     anim1->setEasingCurve(QEasingCurve::Linear);
 
     QPropertyAnimation *anim2 = new QPropertyAnimation(newTimeline,"pos");
     anim2->setStartValue(newTimeline->pos());
-    anim2->setEndValue(centerPos);
+    anim2->setEndValue(_centerPos);
     anim2->setDuration(250);
     anim2->setEasingCurve(QEasingCurve::Linear);
 
@@ -334,13 +350,13 @@ void TimelineView::_moveToRight(KineticList *oldTimeline, KineticList *newTimeli
 {
     QPropertyAnimation *anim1 = new QPropertyAnimation(oldTimeline,"pos");
     anim1->setStartValue(oldTimeline->pos());
-    anim1->setEndValue(rightPos);
+    anim1->setEndValue(_rightPos);
     anim1->setDuration(250);
     anim1->setEasingCurve(QEasingCurve::Linear);
 
     QPropertyAnimation *anim2 = new QPropertyAnimation(newTimeline,"pos");
     anim2->setStartValue(newTimeline->pos());
-    anim2->setEndValue(centerPos);
+    anim2->setEndValue(_centerPos);
     anim2->setDuration(250);
     anim2->setEasingCurve(QEasingCurve::Linear);
 
@@ -369,6 +385,7 @@ void TimelineView::setUpdateMessage(const QString &message)
 void TimelineView::clearText(void)
 {
     _updateButton->enable(true);
+    _entryUpdate->enable(true);
     _entryUpdate->clearText();
 }
 
@@ -381,6 +398,7 @@ void TimelineView::_emitPostUpdate()
     if(_entryUpdate->getText().length() < 141) {
         startLoader();
         _updateButton->enable(false);
+        _entryUpdate->enable(false);
         emit postUpdate();
     }
 }
@@ -399,26 +417,17 @@ void TimelineView::_handleNewMessage(QString newMessage)
  */
 void TimelineView::startLoader()
 {
-    _loader = new Loader(this,QPointF(400,426));
-    _loader->setZValue(5.0);
-    _loader->startEntryAnimation();
-    connect(_loader, SIGNAL(finished()), this, SLOT(_deleteLoader()));
-}
-
-/*! \brief Deletes loader object when loader finishes.
- */
-void TimelineView::_deleteLoader()
-{
-    delete _loader;
-    _loader = NULL;
+    setEnabled(false);
+    _exposeButton->enable(true);
+    loaderEntryAnimation();
 }
 
 /*! \brief This slot is called to start loader's exit animation.
  */
 void TimelineView::endLoader()
 {
-    if(_loader)
-        _loader->startExitAnimation();
+    setEnabled(true);
+    loaderExitAnimation();
 }
 
 /*!
@@ -476,7 +485,7 @@ void TimelineView::_emitUnfollow(QString username, bool _unfollow)
 void TimelineView::_emitDelete(quint64 id, Tweet *tweet)
 {
     startLoader();
-    m_deleteTweet = tweet;
+    _deleteTweet = tweet;
     emit deleteTweet(id);
 }
 
@@ -559,7 +568,7 @@ void TimelineView::_handleReply(QString newMessage, quint64 statusId)
 //    this->_updateButton->enable(true);
 
 //    isReply = true;
-    m_statusId = statusId;
+    _statusId = statusId;
 }
 
 void TimelineView::addMoreButton(Timeline::TimelineType type)
@@ -569,18 +578,98 @@ void TimelineView::addMoreButton(Timeline::TimelineType type)
         case Timeline::Friends:
             _homeTimeline->addMoreButton();
             break;
+
         case Timeline::Mentions:
             _mentionsTimeline->addMoreButton();
             break;
+
+        default:
+            break;
     }
 }
 
 void TimelineView::tweetDeleted(quint64 id)
 {
-    if(m_deleteTweet->getEntry().id == id)
-        _homeTimeline->removeFromList(m_deleteTweet);
+    if(_deleteTweet->getEntry().id == id)
+        _homeTimeline->removeFromList(_deleteTweet);
     else {
         // TODO: error
     }
-    _deleteLoader();
+    endLoader();
+}
+
+void TimelineView::_setTimelinePos(KineticList *timeline)
+{
+    qint32 posX = timeline->pos().x();
+
+    switch(posX) {
+        case -801:
+        case -481:
+            timeline->setPos(_leftPos);
+            break;
+
+        case 0:
+            timeline->setPos(_centerPos);
+            break;
+
+        case 801:
+        case 481:
+            timeline->setPos(_rightPos);
+            break;
+    }
+}
+
+void TimelineView::_changeOrientation(void)
+{
+    QRect screenGeometry = QApplication::desktop()->screenGeometry();
+    resize(screenGeometry.size());
+
+    if(screenGeometry.width() > screenGeometry.height()) {
+        _homeTimeline->setSize(QSizeF(800, 360));
+        _mentionsTimeline->setSize(QSizeF(800, 360));
+
+        _leftPos = QPointF(-801, 60);
+        _centerPos = QPointF(0, 60);
+        _rightPos = QPointF(801, 60);
+
+        _entryUpdatePos = QPointF(0, size().height() - _entryUpdate->size().height());
+        _updateButtonPos = QPointF(size().width() - _updateButton->size().width(),
+                                   size().height() - _updateButton->size().height());
+
+    } else if(screenGeometry.width() < screenGeometry.height()) {
+        _homeTimeline->setSize(QSizeF(480, 677));
+        _mentionsTimeline->setSize(QSizeF(480, 677));
+
+        _leftPos = QPointF(-481, 120);
+        _centerPos = QPointF(0, 120);
+        _rightPos = QPointF(481, 120);
+
+        _entryUpdatePos = QPointF(0, 850);
+        _updateButtonPos = QPointF(0, 850);
+    }
+
+    _entryUpdate->setPos(_entryUpdatePos);
+    _updateButton->setPos(_updateButtonPos);
+
+    _setTimelinePos(_homeTimeline);
+    _setTimelinePos(_mentionsTimeline);
+
+    setLoaderPosition(size().width()/2 - 12, size().height()/2 - 12);
+
+    _createAnimation();
+}
+
+void TimelineView::_unlockRotation(void)
+{
+    _emitLockRotation(false);
+}
+
+void TimelineView::_lockRotation(void)
+{
+    _emitLockRotation(true);
+}
+
+void TimelineView::_emitLockRotation(bool lock)
+{
+    emit lockRotation(lock);
 }
