@@ -25,7 +25,6 @@
 
 #include "backend.h"
 #include "applicationItems/lineedit.h"
-#include "applicationItems/loader.h"
 #include "applicationItems/twitterapplicationitem.h"
 #include "applicationItems/twitterbutton.h"
 #include "applicationItems/twittercheckbox.h"
@@ -45,7 +44,7 @@
  *
  * \brief Timeline window with customized widgets.
  */
-class TimelineView : public QGraphicsWidget
+class TimelineView : public TwitterApplicationItem
 {
     Q_OBJECT
 
@@ -84,9 +83,9 @@ signals:
     void moreHomeTweets(void);
     void moreMentions(void);
     void getTimeline(Timeline::TimelineType);
+    void lockRotation(bool);
 
 private slots:
-    void _deleteLoader(void);
     void _enableTweetButton(QString);
     void _handleNewMessage(QString newMessage);
     void _handleReply(QString newMessage, quint64 statusId);
@@ -103,6 +102,9 @@ private slots:
     void _toHome(void);
     void _toMentions(void);
     void _showIpLocationInfo(double latitude, double longitude);
+    void _changeOrientation(void);
+    void _unlockRotation(void);
+    void _lockRotation(void);
 
 private:
     QAbstractAnimation *_createEntryAnimation(void);
@@ -111,6 +113,7 @@ private:
     void _createButtons(void);
     void _createTopBar(void);
     void _createSettings(void);
+    void _createAnimation(void);
     void _moveToLeft(KineticList*, KineticList*);
     void _moveToRight(KineticList*, KineticList*);
     void _moveTimelines(KineticList*, KineticList*);
@@ -121,6 +124,8 @@ private:
                      TwitterApplicationItem *item,
                      QPointF startValue, QPointF endValue,
                      QEasingCurve easing, int delay);
+    void _setTimelinePos(KineticList *timeline);
+    void _emitLockRotation(bool lock);
 
 private:
     QAbstractAnimation *_exitAnim;
@@ -128,15 +133,18 @@ private:
     KineticList *timelineOnScreen;
     Loader *_loader;
     LineEdit *_entryUpdate;
-    Tweet *m_deleteTweet;
-    QPointF leftPos;
-    QPointF centerPos;
-    QPointF rightPos;
+    Tweet *_deleteTweet;
+    QPointF _leftPos;
+    QPointF _centerPos;
+    QPointF _rightPos;
     QList<KineticList*> _timelines;
     QList<bool> _downloadedTimelines;
 
+    QPointF _updateButtonPos;
+    QPointF _entryUpdatePos;
+
 public:
-    quint64 m_statusId;
+    quint64 _statusId;
     TwitterTopBar *_topBar;
     TwitterTweetInfo *_tweetInfo;
     TwitterButton *_updateButton;
