@@ -31,13 +31,15 @@ Entry::Entry( Entry::Type entryType ) :
         originalText( QString() ),
         timestamp( QDateTime() ),
         localTime( QDateTime() ),
+        parsedTime( QString() ),
         hasInReplyToStatusId( false ),
         inReplyToStatusId( 0 ),
         inReplyToScreenName( QString() ),
         favorited( false ),
         userInfo( UserInfo() ),
         source( QString() ),
-        retweet_count ( 0 )
+        retweet_count ( 0 ),
+        retweeted_status ( NULL )
 {}
 
 void Entry::initialize()
@@ -48,6 +50,7 @@ void Entry::initialize()
     originalText = QString();
     timestamp = QDateTime();
     localTime = QDateTime();
+    parsedTime = QString();
     hasInReplyToStatusId = false;
     inReplyToStatusId = 0;
     inReplyToScreenName = QString();
@@ -55,6 +58,7 @@ void Entry::initialize()
     userInfo.initialize();
     source = QString();
     retweet_count = 0;
+    retweeted_status = new Entry;
 }
 
 bool Entry::checkContents()
@@ -92,12 +96,14 @@ bool Entry::operator== (const Entry &other )
              && userInfo.hasHomepage == other.userInfo.hasHomepage
              && timestamp == other.timestamp
              && localTime == other.localTime
+             && parsedTime == other.parsedTime
              && hasInReplyToStatusId == other.hasInReplyToStatusId
              && inReplyToStatusId == other.inReplyToStatusId
              && inReplyToScreenName == other.inReplyToScreenName
              && favorited == other.favorited
              && source == other.source
-             && retweet_count == other.retweet_count );
+             && retweet_count == other.retweet_count
+             && retweeted_status == other.retweeted_status );
 }
 
 QDataStream& operator<<( QDataStream & out, const Entry &entry )
@@ -109,6 +115,7 @@ QDataStream& operator<<( QDataStream & out, const Entry &entry )
     out << entry.originalText;
     out << entry.timestamp;
     out << entry.localTime;
+    out << entry.parsedTime;
     out << entry.hasInReplyToStatusId;
     out << entry.inReplyToStatusId;
     out << entry.inReplyToScreenName;
@@ -116,6 +123,7 @@ QDataStream& operator<<( QDataStream & out, const Entry &entry )
     out << entry.userInfo;
     out << entry.source;
     out << entry.retweet_count;
+    out << entry.retweeted_status;
     return out;
 }
 
@@ -129,6 +137,7 @@ QDataStream& operator>>( QDataStream & in, Entry &entry )
     in >> entry.originalText;
     in >> entry.timestamp;
     in >> entry.localTime;
+    in >> entry.parsedTime;
     in >> entry.hasInReplyToStatusId;
     in >> entry.inReplyToStatusId;
     in >> entry.inReplyToScreenName;
