@@ -45,6 +45,9 @@ const QString XmlParser::TAG_UTC_OFFSET = "utc_offset";
 const QString XmlParser::TAG_STATUS_COUNT = "statuses_count";
 const QString XmlParser::TAG_SOURCE = "source";
 const QString XmlParser::TAG_RETWEET_COUNT = "retweet_count";
+const QString XmlParser::TAG_FAVOURITES_COUNT = "favourites_count";
+const QString XmlParser::TAG_VERIFIED = "verified";
+const QString XmlParser::TAG_RETWEETED_STATUS = "retweeted_status";
 
 const QString XmlParserDirectMsg::TAG_DIRECT_MESSAGE = "direct_message";
 const QString XmlParserDirectMsg::TAG_SENDER = "sender";
@@ -53,7 +56,8 @@ const QSet<QString> XmlParser::tags = QSet<QString>() << TAG_STATUS_ID << TAG_US
                                       << TAG_USER_IMAGE << TAG_USER_HOMEPAGE << TAG_USER_TIMESTAMP << TAG_INREPLYTO_STATUS_ID
                                       << TAG_INREPLYTO_SCREEN_NAME << TAG_USER_ID << TAG_LOCATION << TAG_DESCRIPTION
                                       << TAG_FOLLOWERS_COUNT << TAG_FRIENDS_COUNT << TAG_STATUS_COUNT << TAG_FAVORITED
-                                      << TAG_UTC_OFFSET << TAG_SOURCE << TAG_RETWEET_COUNT;
+                                      << TAG_UTC_OFFSET << TAG_SOURCE << TAG_RETWEET_COUNT << TAG_FAVOURITES_COUNT << TAG_VERIFIED
+                                      << TAG_RETWEETED_STATUS;
 
 const int XmlParser::timeShift = XmlParser::calculateTimeShift();
 
@@ -64,6 +68,7 @@ XmlParser::XmlParser( const QString &serviceUrl, const QString &login, QObject *
         entry(),
         important( false ),
         parsingUser( false ),
+        parsingRetweet ( false ),
         level( 0 )
 {
     m_serviceUrl = serviceUrl;
@@ -77,6 +82,7 @@ XmlParser::XmlParser( const QString &serviceUrl, const QString &login, Entry::Ty
         entry( entryType ),
         important( false ),
         parsingUser( false ),
+        parsingRetweet ( false ),
         level( 0 )
 {
     m_serviceUrl = serviceUrl;
@@ -118,11 +124,15 @@ bool XmlParser::endDocument()
 bool XmlParser::startElement( const QString & /* namespaceURI */, const QString & /* localName */, const QString &qName, const QXmlAttributes & /*atts*/ )
 {
     ++level;
+    if ( qName == TAG_RETWEETED_STATUS) {
+        entry.retweeted_status->initialize();
+        parsingRetweet = true;
+    }
     if ( qName == TAG_STATUS ) {
         entry.initialize();
         favoritedSet = false;
     }
-    if( qName == TAG_USER && level <= 3 ) {
+    if( qName == TAG_USER ) {
         parsingUser = true;
     }
     important = tags.contains( qName );
@@ -134,6 +144,9 @@ bool XmlParser::startElement( const QString & /* namespaceURI */, const QString
 bool XmlParser::endElement( const QString & /* namespaceURI */, const QString & /* localName */, const QString &qName )
 {
     --level;
+    if ( qName == TAG_RETWEETED_STATUS) {
+        parsingRetweet = false;
+    }
     if ( qName == TAG_STATUS ) {
         data << entry;
     }
@@ -145,46 +158,52 @@ bool XmlParser::endElement( const QString & /* namespaceURI */, const QString &
 
 bool XmlParser::characters( const QString &ch )
 {
+    Entry *pEntry = &entry;
+
+    if( parsingRetweet )
+        pEntry = entry.retweeted_status;
+
     if ( important ) {
         if ( parsingUser ) {
             parseUserInfo(ch);
         } else {
-            if ( currentTag == TAG_STATUS_ID && entry.id == Q_UINT64_C(0) ) {
-                entry.id = ch.toULongLong();
-            } else if ( currentTag == TAG_USER_TEXT && entry.text.isNull() ) {
-                entry.originalText = ch;
-                entry.originalText.replace( "&lt;", "<" );
-                entry.originalText.replace( "&gt;", ">" );
-                entry.text = textToHtml( entry.originalText );
-            } else if ( currentTag == TAG_SOURCE && entry.source.isNull() ) {
+            if ( currentTag == TAG_STATUS_ID && pEntry->id == Q_UINT64_C(0) ) {
+                pEntry->id = ch.toULongLong();
+            } else if ( currentTag == TAG_USER_TEXT && pEntry->text.isNull() ) {
+                pEntry->originalText = ch;
+                pEntry->originalText.replace( "&lt;", "<" );
+                pEntry->originalText.replace( "&gt;", ">" );
+                pEntry->text = textToHtml( pEntry->originalText );
+            } else if ( currentTag == TAG_SOURCE && pEntry->source.isNull() ) {
                 if( !ch.trimmed().isEmpty() ) {
-                    entry.source = ch;
+                    pEntry->source = parseSource(ch);
                 }
-            } else if ( currentTag == TAG_RETWEET_COUNT && entry.retweet_count == 0) {
-                entry.retweet_count = ch.toInt();
-            } else if ( currentTag == TAG_USER_TIMESTAMP && entry.timestamp.isNull() ) {
-                entry.timestamp = toDateTime( ch ); //utc
+            } else if ( currentTag == TAG_RETWEET_COUNT && pEntry->retweet_count == 0) {
+                pEntry->retweet_count = ch.toInt();
+            } else if ( currentTag == TAG_USER_TIMESTAMP && pEntry->timestamp.isNull() ) {
+                pEntry->timestamp = toDateTime( ch ); //utc
                 /* It's better to leave UTC timestamp alone; Additional member localTime is added to store local time when
          user's system supports timezones. */
-                entry.localTime = entry.timestamp.addSecs( timeShift ); //now - utc
-            } else if ( currentTag == TAG_INREPLYTO_STATUS_ID && entry.inReplyToStatusId == 0) {
+                pEntry->localTime = pEntry->timestamp.addSecs( timeShift ); //now - utc
+                pEntry->parsedTime = parseCreatedAt(pEntry->localTime);
+            } else if ( currentTag == TAG_INREPLYTO_STATUS_ID && pEntry->inReplyToStatusId == 0) {
                 if( !ch.trimmed().isEmpty() ) {
                     /* In reply to status id exists and is not empty; Hack for dealing with tags that are opened and closed
            at the same time, e.g. <in_reply_to_screen_name/>  */
-                    entry.hasInReplyToStatusId = true;
-                    entry.inReplyToStatusId = ch.toULongLong();
+                    pEntry->hasInReplyToStatusId = true;
+                    pEntry->inReplyToStatusId = ch.toULongLong();
                 }
-            } else if ( currentTag == TAG_INREPLYTO_SCREEN_NAME && entry.hasInReplyToStatusId ) {
+            } else if ( currentTag == TAG_INREPLYTO_SCREEN_NAME && pEntry->hasInReplyToStatusId ) {
                 /* When hasInReplyToStatusId is true, inReplyToScreenName should be present, but it won't hurt to check it again
          just in case */
                 if( !ch.trimmed().isEmpty() ) {
-                    entry.inReplyToScreenName = ch;
+                    pEntry->inReplyToScreenName = ch;
                 }
             } else if ( currentTag == TAG_FAVORITED && !favoritedSet ) {
                 if ( ch.compare("false") == 0 )
-                    entry.favorited = false;
+                    pEntry->favorited = false;
                 else
-                    entry.favorited = true;
+                    pEntry->favorited = true;
                 favoritedSet = true;
             }
         }
@@ -196,42 +215,108 @@ bool XmlParser::characters( const QString &ch )
 
 void XmlParser::parseUserInfo(const QString &ch)
 {
-    if ( currentTag == TAG_USER_ID && parsingUser && entry.userInfo.id == -1 ) {
-        entry.userInfo.id = ch.toInt();
-    } else if ( currentTag == TAG_USER_NAME && entry.userInfo.name.isNull() ) {
-        entry.userInfo.name = ch;
-    } else if ( currentTag == TAG_USER_SCREENNAME && entry.userInfo.screenName.isNull() ) {
-        entry.userInfo.screenName = ch;
-        if ( entry.userInfo.screenName == m_login )
-            entry.isOwn = true;
+    Entry *pEntry = &entry;
+
+    if( parsingRetweet )
+        pEntry = entry.retweeted_status;
+
+    if ( currentTag == TAG_USER_ID && parsingUser && pEntry->userInfo.id == -1 ) {
+        pEntry->userInfo.id = ch.toInt();
+    } else if ( currentTag == TAG_USER_NAME && pEntry->userInfo.name.isNull() ) {
+        pEntry->userInfo.name = ch;
+    } else if ( currentTag == TAG_USER_SCREENNAME && pEntry->userInfo.screenName.isNull() ) {
+        pEntry->userInfo.screenName = ch;
+        if ( pEntry->userInfo.screenName == m_login )
+            pEntry->isOwn = true;
     } else if ( currentTag == TAG_USER_HOMEPAGE ) {
         if ( !ch.trimmed().isEmpty() ) {
-            entry.userInfo.hasHomepage = true;
-            entry.userInfo.homepage = ch;
-            if ( entry.userInfo.homepage.endsWith( '/' ) )
-                entry.userInfo.homepage.chop(1);
+            pEntry->userInfo.hasHomepage = true;
+            pEntry->userInfo.homepage = ch;
+            if ( pEntry->userInfo.homepage.endsWith( '/' ) )
+                pEntry->userInfo.homepage.chop(1);
         }
-    } else if ( currentTag == TAG_USER_IMAGE && entry.userInfo.imageUrl.isNull() ) {
-        entry.userInfo.imageUrl = ch;
-    } else if ( currentTag == TAG_LOCATION && entry.userInfo.location.isNull() ) {
+    } else if ( currentTag == TAG_USER_IMAGE && pEntry->userInfo.imageUrl.isNull() ) {
+        pEntry->userInfo.imageUrl = ch;
+    } else if ( currentTag == TAG_LOCATION && pEntry->userInfo.location.isNull() ) {
         if( !ch.trimmed().isEmpty() ) {
-            entry.userInfo.location = ch;
+            pEntry->userInfo.location = ch;
         }
-    } else if ( currentTag == TAG_DESCRIPTION && entry.userInfo.description.isNull() ) {
+    } else if ( currentTag == TAG_DESCRIPTION && pEntry->userInfo.description.isNull() ) {
         if( !ch.trimmed().isEmpty() ) {
-            entry.userInfo.description = ch;
+            pEntry->userInfo.description = ch;
         }
-    } else if ( currentTag == TAG_FRIENDS_COUNT && entry.userInfo.friendsCount == -1 ) {
-        entry.userInfo.friendsCount = ch.toInt();
-    } else if ( currentTag == TAG_FOLLOWERS_COUNT && entry.userInfo.followersCount == -1 ) {
-        entry.userInfo.followersCount = ch.toInt();
-    } else if ( currentTag == TAG_STATUS_COUNT && entry.userInfo.statusesCount == -1 ) {
-        entry.userInfo.statusesCount = ch.toInt();
-    } else if ( currentTag == TAG_UTC_OFFSET && entry.userInfo.utcOffset == -1 ) {
-        entry.userInfo.utcOffset = ch.toInt();
+    } else if ( currentTag == TAG_FRIENDS_COUNT && pEntry->userInfo.friendsCount == -1 ) {
+        pEntry->userInfo.friendsCount = ch.toInt();
+    } else if ( currentTag == TAG_FOLLOWERS_COUNT && pEntry->userInfo.followersCount == -1 ) {
+        pEntry->userInfo.followersCount = ch.toInt();
+    } else if ( currentTag == TAG_FAVOURITES_COUNT && pEntry->userInfo.favouritesCount == -1) {
+        pEntry->userInfo.favouritesCount = ch.toInt();
+    } else if ( currentTag == TAG_STATUS_COUNT && pEntry->userInfo.statusesCount == -1 ) {
+        pEntry->userInfo.statusesCount = ch.toInt();
+    } else if ( currentTag == TAG_UTC_OFFSET && pEntry->userInfo.utcOffset == -1 ) {
+        pEntry->userInfo.utcOffset = ch.toInt();
+    } else if ( currentTag == TAG_VERIFIED && pEntry->userInfo.verified == false ) {
+        if ( ch.compare("false") == 0 )
+            pEntry->userInfo.verified = false;
+        else
+            pEntry->userInfo.verified = true;
     }
 }
 
+QString XmlParser::parseSource(QString source)
+{
+    return source.remove(QRegExp("<[^<]*>"));
+}
+
+/*!
+ * \brief This funcion is a parser for writting the time of user tweet
+ * \param source The list with the time of the tweets
+ * \return A list with only the time of the tweets
+ */
+QString XmlParser::parseCreatedAt(QDateTime timestamp)
+{
+    QLocale::setDefault(QLocale::English);
+
+    QString newCreatedAt;
+    int seconds = timestamp.secsTo(QDateTime::currentDateTime().toUTC());
+
+    if (seconds < 20) {
+        newCreatedAt = "Less than 20 seconds ago";
+    } else if(seconds < 30) {
+        newCreatedAt = "About half minute ago";
+    } else if(seconds < 60) {
+        newCreatedAt = "Less than 1 minute ago";
+    } else if(seconds < 120) {
+        newCreatedAt = "About 1 minute ago";
+    } else if(seconds < 3600) {
+        newCreatedAt = QString::number(seconds/60) + " minutes ago";
+    } else if(seconds < 7200) {
+        newCreatedAt = "About 1 hour ago";
+    } else if(seconds < 86400) {
+        newCreatedAt = "About " + QString::number(seconds/3600) + " hours ago";
+    } else {
+        newCreatedAt = QString::number(timestamp.time().hour()) + ":" +
+                       QString::number(timestamp.time().minute()) + " " +
+                       QDate::shortMonthName(timestamp.date().month()) + " " +
+                       QString::number(timestamp.date().day());
+
+        switch(timestamp.date().day()) {
+            case 1:
+            case 21:
+                newCreatedAt += "st "; break;
+            case 2:
+            case 22:
+                newCreatedAt += "nd "; break;
+            case 3:
+                newCreatedAt += "rd "; break;
+            default:
+                newCreatedAt += "th "; break;
+        }
+    }
+
+    return newCreatedAt;
+}
+
 QDateTime XmlParser::toDateTime( const QString &timestamp )
 {
     QRegExp rx( "(\\w+) (\\w+) (\\d{2}) (\\d{1,2}):(\\d{2}):(\\d{2}) .+ (\\d{4})" );
@@ -282,37 +367,26 @@ int XmlParser::calculateTimeShift()
 QString XmlParser::textToHtml( QString newText )
 {
     // URL_IDENTICA = http://identi.ca/api
-    QString networkUrl = m_serviceUrl.replace( QRegExp( "/api$" ), "" );
     newText.replace( "<", "&lt;" );
     newText.replace( ">", "&gt;" );
 
+    // recognize #hashtags
+    QRegExp tag( "#([\\w\\d-]+)( ?)", Qt::CaseInsensitive );
+    newText.replace( tag, "<font color=#0f95da>#\\1</font>\\2");
+
     // recognize web/ftp links
     QRegExp ahref( "((https?|ftp)://[^ ]+)( ?)", Qt::CaseInsensitive );
-    newText.replace( ahref, "<a href='\\1'>\\1</a>\\3" );
+    newText.replace( ahref, "<font color=#0f95da>\\1</font>\\3" );
 
     // recognize @mentions (letters, numbers are allowed in nicks)
     // for Twitter, also allow _ in nicks and @user/list;
     // the list name can only contain letters, numbers and dashes (-)
-    newText.replace( m_serviceUrl == TwitterAPI::UrlTwitter ?
-                     QRegExp( "(^|[^a-zA-Z0-9])@([\\w\\d_]+(/[\\w\\d-]+)?)" ) :
-                     QRegExp( "(^|[^a-zA-Z0-9])@([\\w\\d]+)" ),
-                     QString( "\\1<a href='%1/\\2'>@\\2</a>").arg( networkUrl ) );
+    newText.replace( QRegExp( "(^|[^a-zA-Z0-9])@([\\w\\d_]+(/[\\w\\d-]+)?)" ),
+                  QString( "\\1@<font color=#0f95da>\\2</font>"));
 
-    // recognize e-mail addresses
-    QRegExp mailto( "([a-z0-9\\._%-]+@[a-z0-9\\.-]+\\.[a-z]{2,4})", Qt::CaseInsensitive );
-    newText.replace( mailto, "<a href='mailto:\\1'>\\1</a>" );
-
-    // recognize #hashtags
-    QRegExp tag( "#([\\w\\d-]+)( ?)", Qt::CaseInsensitive );
-    newText.replace( tag, m_serviceUrl == TwitterAPI::UrlTwitter ?
-                     "<a href='http://search.twitter.com/search?q=\\1'>#\\1</a>\\2" :
-                     QString( "<a href='%1/tag/\\1'>#\\1</a>\\2" ).arg(networkUrl) );
-
-    // recognize !groups
-    if ( m_serviceUrl != TwitterAPI::UrlTwitter ) {
-        QRegExp group( "!([\\w\\d-]+)( ?)", Qt::CaseInsensitive );
-        newText.replace( group, QString( "<a href='%1/group/\\1'>!\\1</a>\\2" ).arg(networkUrl) );
-    }
+    // TODO: recognize e-mail addresses
+//    QRegExp mailto( "([a-z0-9\\._%-]+@[a-z0-9\\.-]+\\.[a-z]{2,4})", Qt::CaseInsensitive );
+//    newText.replace( mailto, "<a href='mailto:\\1'>\\1</a>" );
 
     return newText;
 }
@@ -351,7 +425,7 @@ bool XmlParserDirectMsg::endElement( const QString & /* namespaceURI */, const Q
 bool XmlParserDirectMsg::characters( const QString &ch )
 {
     if ( important ) {
-        if (parsingSender)
+        if ( parsingSender )
             parseUserInfo(ch);
         else {
             if ( currentTag == TAG_STATUS_ID && entry.id == Q_UINT64_C(0) ) {
@@ -362,6 +436,7 @@ bool XmlParserDirectMsg::characters( const QString &ch )
             } else if ( currentTag == TAG_USER_TIMESTAMP && entry.timestamp.isNull() ) {
                 entry.timestamp = toDateTime( ch );
                 entry.localTime = entry.timestamp.addSecs( timeShift );
+                entry.parsedTime = parseCreatedAt(entry.localTime);
             }
         }
     }
